@@ -5,7 +5,7 @@
  | Password Plugin for Roundcube                                           |
  | @version @package_version@                                                             |
  |                                                                         |
- | Copyright (C) 2009, Roundcube Dev.                                      |
+ | Copyright (C) 2009-2010, Roundcube Dev.                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or modify    |
  | it under the terms of the GNU General Public License version 2          |
@@ -46,7 +46,9 @@ define('PASSWORD_SUCCESS', 0);
  */
 class password extends rcube_plugin
 {
-    public $task = 'settings';
+    public $task    = 'settings';
+    public $noframe = true;
+    public $noajax  = true;
 
     function init()
     {
@@ -124,9 +126,17 @@ class password extends rcube_plugin
                 $rcmail->output->command('display_message', $this->gettext('passwordweak'), 'error');
             }
             // try to save the password
-            else if (!($res = $this->_save($curpwd,$newpwd))) {
+            else if (!($res = $this->_save($curpwd, $newpwd))) {
                 $rcmail->output->command('display_message', $this->gettext('successfullysaved'), 'confirmation');
+
+                // Reset session password
                 $_SESSION['password'] = $rcmail->encrypt($newpwd);
+
+                // Log password change
+                if ($rcmail->config->get('password_log')) {
+                    write_log('password', sprintf('Password changed for user %s (ID: %d) from %s',
+                        $rcmail->user->get_username(), $rcmail->user->ID, rcmail_remote_ip()));
+                }
             }
             else {
                 $rcmail->output->command('display_message', $res, 'error');
@@ -229,18 +239,27 @@ class password extends rcube_plugin
 
         $result = password_save($curpass, $passwd);
 
+        if (is_array($result)) {
+            $message = $result['message'];
+            $result  = $result['code'];
+        }
+
         switch ($result) {
             case PASSWORD_SUCCESS:
                 return;
             case PASSWORD_CRYPT_ERROR;
-                return $this->gettext('crypterror');
+                $reason = $this->gettext('crypterror');
             case PASSWORD_CONNECT_ERROR;
-                return $this->gettext('connecterror');
+                $reason = $this->gettext('connecterror');
             case PASSWORD_ERROR:
             default:
-                return $this->gettext('internalerror');
+                $reason = $this->gettext('internalerror');
         }
+
+        if ($message) {
+            $reason .= ' ' . $message;
+        }
+
+        return $reason;
     }                                     
 }
-
-?>
